@@ -137,6 +137,8 @@ const ConnectedAutocomplete = ({
         getEndpoint={getEndpoint}
         decoder={connectedAutocomplete?.decoder}
         getRenderedOptionText={connectedAutocomplete?.getRenderedOptionText}
+        getOptionLabel={connectedAutocomplete?.getOptionLabel}
+        optionProperty={connectedAutocomplete?.optionProperty}
         initialPage={1}
         isOptionEqualToValue={isOptionEqualToValue}
         label={t(label)}
