@@ -1,7 +1,7 @@
 import { EmptyRow } from '../Row/EmptyRow';
 
 interface EmptyResultProps {
-  label: string;
+  label: string | JSX.Element;
 }
 
 const EmptyResult = ({ label }: EmptyResultProps): JSX.Element => (
