@@ -1,5 +1,3 @@
-/* eslint-disable react/no-array-index-key */
-
 import { useAtomValue } from 'jotai';
 import {
   concat,
@@ -49,7 +47,6 @@ import DataCell from './Cell/DataCell';
 import Checkbox from './Checkbox';
 import { EmptyResult } from './EmptyResult/EmptyResult';
 import { ListingHeader } from './Header';
-import { useListingStyles } from './Listing.styles';
 import ListingRow from './Row/Row';
 import { SkeletonLoader } from './Row/SkeletonLoaderRows';
 import {
@@ -61,8 +58,8 @@ import {
   SortOrder
 } from './models';
 import { subItemsPivotsAtom } from './tableAtoms';
-import { labelNoResultFound } from './translatedLabels';
-import useStyleTable from './useStyleTable';
+import { labelNoResultFound as defaultLabelNoResultFound } from './translatedLabels';
+import useStyleTable, { useColumnStyle } from './useStyleTable';
 
 const subItemPrefixKey = 'listing';
 
@@ -139,6 +136,8 @@ export interface Props<TRow> {
   totalRows?: number;
   viewerModeConfiguration?: ViewerModeConfiguration;
   widthToMoveTablePagination?: number;
+  isActionBarVisible: boolean;
+  labelNoResultFound?: string | JSX.Element;
 }
 
 const defaultColumnConfiguration = {
@@ -147,7 +146,13 @@ const defaultColumnConfiguration = {
 
 export const performanceRowsLimit = 60;
 
-const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
+const Listing = <
+  TRow extends {
+    id: RowId;
+    internalListingParentId?: RowId;
+    internalListingParentRow: TRow;
+  }
+>({
   customListingComponent,
   displayCustomListing,
   limit = 10,
@@ -191,17 +196,21 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
     getRowProperty: () => '',
     labelCollapse: 'Collapse',
     labelExpand: 'Expand'
-  }
+  },
+  isActionBarVisible = true,
+  labelNoResultFound = defaultLabelNoResultFound
 }: Props<TRow>): JSX.Element => {
   const currentVisibleColumns = getVisibleColumns({
     columnConfiguration,
     columns
   });
-  const { dataStyle, getGridTemplateColumn } = useStyleTable({
-    checkable,
-    currentVisibleColumns,
+  const { dataStyle } = useStyleTable({
     listingVariant
   });
+  const gridTemplateColumn = useColumnStyle({
+    checkable,
+    currentVisibleColumns
+  });
 
   const { t } = useTranslation();
 
@@ -246,7 +255,8 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
                   row,
                   ...row[subItems.getRowProperty()].map((subRow) => ({
                     ...subRow,
-                    internalListingParentId: row.id
+                    internalListingParentId: row.id,
+                    internalListingParentRow: row
                   }))
                 ];
               }
@@ -277,14 +287,6 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
     },
     [allSubItemIds]
   );
-
-  const { classes } = useListingStyles({
-    dataStyle,
-    getGridTemplateColumn,
-    isResponsive,
-    rows: rowsToDisplay
-  });
-
   const { isShiftKeyDown } = useKeyObserver();
 
   const haveSameId = (row: TRow, rowToCompare: TRow): boolean =>
@@ -506,41 +508,43 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
   const areColumnsEditable = not(isNil(onSelectColumns));
 
   return (
-    <div className={classes.listingContainer}>
+    <div className="h-full w-full overflow-hidden">
       {loading && rows.length > 0 && (
-        <LinearProgress className={classes.loadingIndicator} />
+        <LinearProgress className="w-full h-[3px]" />
       )}
       {(!loading || (loading && rows.length < 1)) && (
-        <div className={classes.loadingIndicator} />
+        <div className="w-full h-[3px]" />
       )}
       <div
-        className={classes.container}
+        className="bg-[none] flex flex-col h-full w-full"
         ref={containerRef as RefObject<HTMLDivElement>}
       >
-        <div
-          className={classes.actionBar}
-          ref={actionBarRef as RefObject<HTMLDivElement>}
-        >
-          <ListingActionBar
-            actions={actions}
-            actionsBarMemoProps={actionsBarMemoProps}
-            columnConfiguration={columnConfiguration}
-            columns={columns}
-            currentPage={currentPage}
-            customPaginationClassName={customPaginationClassName}
-            limit={limit}
-            listingVariant={listingVariant}
-            moveTablePagination={moveTablePagination}
-            paginated={paginated}
-            totalRows={totalRows}
-            viewerModeConfiguration={viewerModeConfiguration}
-            widthToMoveTablePagination={widthToMoveTablePagination}
-            onLimitChange={changeLimit}
-            onPaginate={onPaginate}
-            onResetColumns={onResetColumns}
-            onSelectColumns={onSelectColumns}
-          />
-        </div>
+        {isActionBarVisible && (
+          <div
+            className="flex items-center"
+            ref={actionBarRef as RefObject<HTMLDivElement>}
+          >
+            <ListingActionBar
+              actions={actions}
+              actionsBarMemoProps={actionsBarMemoProps}
+              columnConfiguration={columnConfiguration}
+              columns={columns}
+              currentPage={currentPage}
+              customPaginationClassName={customPaginationClassName}
+              limit={limit}
+              listingVariant={listingVariant}
+              moveTablePagination={moveTablePagination}
+              paginated={paginated}
+              totalRows={totalRows}
+              viewerModeConfiguration={viewerModeConfiguration}
+              widthToMoveTablePagination={widthToMoveTablePagination}
+              onLimitChange={changeLimit}
+              onPaginate={onPaginate}
+              onResetColumns={onResetColumns}
+              onSelectColumns={onSelectColumns}
+            />
+          </div>
+        )}
 
         <ParentSize
           parentSizeStyles={{
@@ -551,7 +555,7 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
         >
           {({ height }) => (
             <Box
-              className={classes.tableWrapper}
+              className="border-b-[none] overflow-auto"
               component="div"
               style={{
                 height: innerScrollDisabled ? '100%' : `calc(${height}px - 4px)`
@@ -562,7 +566,13 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
               ) : (
                 <Table
                   stickyHeader
-                  className={classes.table}
+                  className="grid items-center relative"
+                  style={{
+                    gridTemplateColumns: gridTemplateColumn,
+                    gridTemplateRows: `${dataStyle.header.height}px repeat(${
+                      rowsToDisplay.length || 1
+                    }, ${isResponsive ? 'auto' : `${dataStyle.body.height}px`})`
+                  }}
                   component="div"
                   size="small"
                 >
@@ -585,7 +595,7 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
                   />
 
                   <TableBody
-                    className={classes.tableBody}
+                    className="contents relative"
                     component="div"
                     onMouseLeave={clearHoveredRow}
                   >
@@ -636,7 +646,7 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
                             (!isSubItem || subItems.canCheckSubItems ? (
                               <Cell
                                 align="left"
-                                className={classes.checkbox}
+                                className="justify-start"
                                 disableRowCondition={disableRowCondition}
                                 isRowHovered={isRowHovered}
                                 row={row}
@@ -649,9 +659,12 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
                                     disableRowCheckCondition(row) ||
                                     disableRowCondition(row)
                                   }
-                                  inputProps={{
-                                    'aria-label': `Select row ${getId(row)}`
+                                  slotProps={{
+                                    input: {
+                                      'aria-label': `Select row ${getId(row)}`
+                                    }
                                   }}
+                                  className="pl-1"
                                 />
                               </Cell>
                             ) : (
@@ -692,7 +705,13 @@ const Listing = <TRow extends { id: RowId; internalListingParentId?: RowId }>({
                       (loading ? (
                         <SkeletonLoader rows={limit} />
                       ) : (
-                        <EmptyResult label={t(labelNoResultFound)} />
+                        <EmptyResult
+                          label={
+                            labelNoResultFound
+                              ? t(labelNoResultFound)
+                              : t(defaultLabelNoResultFound)
+                          }
+                        />
                       ))}
                   </TableBody>
                 </Table>
@@ -728,6 +747,7 @@ export const MemoizedListing = <TRow extends { id: string | number }>({
   moveTablePagination,
   widthToMoveTablePagination,
   listingVariant,
+  labelNoResultFound,
   ...props
 }: MemoizedListingProps<TRow>): JSX.Element =>
   useMemoComponent({
@@ -750,6 +770,7 @@ export const MemoizedListing = <TRow extends { id: string | number }>({
         sortOrder={sortOrder}
         totalRows={totalRows}
         widthToMoveTablePagination={widthToMoveTablePagination}
+        labelNoResultFound={labelNoResultFound}
         {...props}
       />
     ),
@@ -772,7 +793,8 @@ export const MemoizedListing = <TRow extends { id: string | number }>({
       sortOrder,
       sortField,
       innerScrollDisabled,
-      listingVariant
+      listingVariant,
+      labelNoResultFound
     ]
   });
 
