@@ -1,7 +1,5 @@
 import { ReactElement, ReactNode } from 'react';
 
-import { useStyles } from './AreaIndicator.styles';
-
 type AreaIndicatorProps = {
   children?: ReactNode | Array<ReactNode>;
   depth?: number;
@@ -17,16 +15,16 @@ const AreaIndicator = ({
   height = '100%',
   depth = 0
 }: AreaIndicatorProps): ReactElement => {
-  const { classes } = useStyles();
-
   return (
     <div
-      className={classes.areaIndicator}
+      className={'bg-secondary-main/25 min-h-8 grid grid-cols-[3fr_1fr]'}
       data-depth={depth}
       style={{ height, width }}
     >
-      {/* eslint-disable-next-line jsx-a11y/label-has-associated-control */}
-      <label>{name}</label>
+      {/* biome-ignore lint/a11y: */}
+      <label className="left-2 rounded-sm border border-[#9747FF7F] border-dashed text-[#9747FF] text-[0.75rem] font-medium left-2 top-1.5 px-2 py-0.5">
+        {name}
+      </label>
       {children}
     </div>
   );
