@@ -69,7 +69,7 @@ class AssertionException extends \Assert\InvalidArgumentException
         int $code = 0,
         ?string $propertyPath = null,
         mixed $value = null,
-        array $constraints = []
+        array $constraints = [],
     ) {
         parent::__construct($message, $code, $propertyPath, $value, $constraints);
     }
@@ -86,7 +86,7 @@ class AssertionException extends \Assert\InvalidArgumentException
     public static function unauthorizedCharacters(
         string $value,
         string $unauthorizedCharacters,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         return new self(
             sprintf(
@@ -114,7 +114,7 @@ class AssertionException extends \Assert\InvalidArgumentException
         string $value,
         int $valueLength,
         int $maxLength,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         return new self(
             sprintf(
@@ -147,7 +147,7 @@ class AssertionException extends \Assert\InvalidArgumentException
         string $value,
         int $valueLength,
         int $minLength,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         return new self(
             sprintf(
@@ -263,7 +263,7 @@ class AssertionException extends \Assert\InvalidArgumentException
     public static function maxDate(
         \DateTimeInterface $date,
         \DateTimeInterface $maxDate,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         $value = $date->format('c');
 
@@ -292,7 +292,7 @@ class AssertionException extends \Assert\InvalidArgumentException
     public static function minDate(
         \DateTimeInterface $date,
         \DateTimeInterface $minDate,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         $value = $date->format('c');
 
@@ -430,7 +430,7 @@ class AssertionException extends \Assert\InvalidArgumentException
         int|float $value,
         int|float $minValue,
         int|float $maxValue,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         return new self(
             sprintf(
@@ -503,7 +503,7 @@ class AssertionException extends \Assert\InvalidArgumentException
     public static function badInstanceOfObject(
         string $objectInstanceName,
         string $instanceNameRequired,
-        ?string $propertyPath = null
+        ?string $propertyPath = null,
     ): self {
         return new self(
             sprintf(
