@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2019 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Infrastructure\ServiceConfiguration;
@@ -43,9 +44,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
 {
     use AccessControlListRepositoryTrait;
 
-    /**
-     * @var SqlRequestParametersTranslator
-     */
+    /** @var SqlRequestParametersTranslator */
     private $sqlRequestTranslator;
 
     public function __construct(DatabaseConnection $db, SqlRequestParametersTranslator $sqlRequestTranslator)
@@ -64,7 +63,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
     {
         // We avoid to start again a database transaction
         $isAlreadyInTransaction = $this->db->inTransaction();
-        if (!$isAlreadyInTransaction) {
+        if (! $isAlreadyInTransaction) {
             $this->db->beginTransaction();
         }
         $addServiceStatement = $this->db->prepare(
@@ -110,7 +109,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                     \PDO::PARAM_STR
                 );
                 $addServiceStatement->execute();
-                $serviceId = (int)$this->db->lastInsertId();
+                $serviceId = (int) $this->db->lastInsertId();
 
                 /**
                  * Create service extension
@@ -137,12 +136,13 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                 $addRelationStatement->execute();
             }
         } catch (\Throwable $ex) {
-            if (!$isAlreadyInTransaction) {
+            if (! $isAlreadyInTransaction) {
                 $this->db->rollBack();
             }
+
             throw $ex;
         }
-        if (!$isAlreadyInTransaction) {
+        if (! $isAlreadyInTransaction) {
             $this->db->commit();
         }
     }
@@ -168,6 +168,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                 $record
             );
         }
+
         return null;
     }
 
@@ -219,7 +220,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
         $serviceMacros = [];
         $loop = [];
         $macrosAdded = [];
-        while (!is_null($serviceId)) {
+        while (! is_null($serviceId)) {
             if (isset($loop[$serviceId])) {
                 break;
             }
@@ -238,7 +239,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                     $record
                 );
             }
-            if (!$isUsingInheritance) {
+            if (! $isUsingInheritance) {
                 break;
             }
         }
@@ -281,7 +282,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
 
         $serviceMacros = [];
         $loop = [];
-        while (!is_null($serviceId)) {
+        while (! is_null($serviceId)) {
             if (isset($loop[$serviceId])) {
                 break;
             }
@@ -289,8 +290,8 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
             $statement->bindValue(':service_id', $serviceId, \PDO::PARAM_INT);
             $statement->execute();
             $record = $statement->fetch(\PDO::FETCH_ASSOC);
-            if (!is_null($record['command_line'])) {
-                return (string)$record['command_line'];
+            if (! is_null($record['command_line'])) {
+                return (string) $record['command_line'];
             }
             $serviceId = $record['service_template_model_stm_id'];
         }
@@ -339,6 +340,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                 ->setHostTemplate($hostTemplate)
                 ->setServiceTemplate($serviceTemplate);
         }
+
         return $hostTemplateServices;
     }
 
@@ -369,6 +371,7 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
                 'service_'
             );
         }
+
         return $services;
     }
 
@@ -378,10 +381,10 @@ class ServiceConfigurationRepositoryRDB extends AbstractRepositoryDRB implements
     public function removeServicesOnHost(int $hostId): void
     {
         $request = $this->translateDbName(
-            "DELETE service FROM `:db`.service
+            'DELETE service FROM `:db`.service
             INNER JOIN `:db`.host_service_relation hsr
                 ON hsr.service_service_id = service.service_id
-            WHERE hsr.host_host_id = :host_id"
+            WHERE hsr.host_host_id = :host_id'
         );
         $statement = $this->db->prepare($request);
         $statement->bindValue(':host_id', $hostId, \PDO::PARAM_INT);
