@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -41,6 +41,8 @@ use Core\Metric\Domain\Model\MetricInformation\ThresholdInformation;
  *     metric_legend: string,
  *     unit: string,
  *     hidden: int,
+ *     host_name: ?string,
+ *     service_name: ?string,
  *     legend: string,
  *     virtual: int,
  *     stack: int,
@@ -82,9 +84,10 @@ use Core\Metric\Domain\Model\MetricInformation\ThresholdInformation;
  *  }
  * @phpstan-type _MetricData array{
  *     global: array{
- *         base: int,
+ *         base: int|null,
  *         title: string,
- *         host_name: string
+ *         host_name: string,
+ *         service_description: string
  *     },
  *     metrics: array<_Metrics>,
  *     times: string[]
@@ -129,7 +132,10 @@ class PerformanceMetricsDataFactory
         $times = [];
         foreach ($metricsData as $index => $metricData) {
             $metricBases[] = $metricData['global']['base'];
-            $metrics['index:' . $index . ';host_name:' . $metricData['global']['host_name']] = $metricData['metrics'];
+            $metrics[
+                'index:' . $index . ';host_name:' . $metricData['global']['host_name'] . ';service_name:'
+                    . $metricData['global']['service_description']
+            ] = $metricData['metrics'];
             $times[] = $metricData['times'];
         }
 
@@ -143,13 +149,13 @@ class PerformanceMetricsDataFactory
     /**
      * Get The highest base of all metrics.
      *
-     * @param int[] $bases
+     * @param array<int, int|null> $bases
      *
      * @return int
      */
     private function getHighestBase(array $bases): int
     {
-        return max($bases);
+        return max($bases) ?? PerformanceMetricsData::DEFAULT_BASE;
     }
 
     /**
@@ -175,15 +181,28 @@ class PerformanceMetricsDataFactory
     {
         $metrics = [];
         foreach ($metricsData as $hostName => $metricData) {
-            \preg_match('/^index:\d+;host_name:([[:ascii:]]+)$/', $hostName, $matches);
+            \preg_match('/^index:\d+;host_name:([[:ascii:]]+);service_name:([[:ascii:]]+)$/', $hostName, $matches);
+
+            // Regarding this, currently if hostname is empty it means that we are dealing with a metaservice
+            $hostName = '';
+            $serviceName = '';
             if ($matches !== []) {
                 $hostName = $matches[1];
+                $serviceName = $matches[2];
             }
             foreach ($metricData as $metric) {
                 if (in_array($metric['metric'], $metricNames, true)) {
-                    $metric['metric'] = $hostName . ': ' . $metric['metric'];
-                    $metric['metric_legend'] = $hostName . ': ' . $metric['metric_legend'];
-                    $metric['legend'] = $hostName . ': ' . $metric['legend'];
+                    $metric['metric_legend'] = ! empty($hostName)
+                        ? $hostName . ': ' . $metric['metric_legend']
+                        : $metric['metric_legend'];
+
+                    $metric['legend'] = ! empty($hostName)
+                        ? $hostName . ': ' . $metric['legend']
+                        : $metric['legend'];
+
+                    $metric['host_name'] = empty($hostName) ? null : $hostName;
+                    $metric['service_name'] = empty($serviceName) ? null : $serviceName;
+
                     $metrics[] = $metric;
                 }
             }
@@ -227,6 +246,8 @@ class PerformanceMetricsDataFactory
                     $metric['metric_legend'],
                     $metric['unit'],
                     (bool) $metric['hidden'],
+                    $metric['host_name'],
+                    $metric['service_name'],
                     $metric['legend'],
                     (bool) $metric['virtual'],
                     (bool) $metric['stack'],
