@@ -32,7 +32,7 @@ final class HostMacroFactory
      * Create macros object from the request data.
      * Use direct and inherited macros to retrieve value of macro with isPassword when not provided in dto.
      *
-     * @param array{name:string,value:string|null,is_password:bool,description:string|null} $data
+     * @param array{id?:int|null,name:string,value:string|null,is_password:bool,description:string|null} $data
      * @param int $hostId
      * @param array<string,Macro> $inheritedMacros
      *
@@ -58,6 +58,7 @@ final class HostMacroFactory
         }
 
         $macro = new Macro(
+            $data['id'] ?? null,
             $hostId,
             $data['name'],
             $macroValue,
