@@ -46,7 +46,7 @@ final class FindMetricsByService
         private ContactInterface $user,
         private ReadMetricRepositoryInterface $metricRepository,
         private ReadAccessGroupRepositoryInterface $accessGroupRepository,
-        private RequestParametersInterface $requestParameters
+        private RequestParametersInterface $requestParameters,
     ) {
     }
 
@@ -58,7 +58,7 @@ final class FindMetricsByService
     public function __invoke(
         int $hostId,
         int $serviceId,
-        FindMetricsByServicePresenterInterface $presenter
+        FindMetricsByServicePresenterInterface $presenter,
     ): void {
         try {
             $this->info('Finding metrics for service', ['id' => $serviceId]);
@@ -74,7 +74,7 @@ final class FindMetricsByService
                 );
             }
 
-            if ([] === $metrics) {
+            if ($metrics === []) {
                 $presenter->presentResponse(new NotFoundResponse('metrics'));
             } else {
                 $presenter->presentResponse($this->createResponse($metrics));
