@@ -37,7 +37,7 @@ class TimePeriod
      */
     public function __construct(
         private readonly int $id,
-        private readonly string $name
+        private readonly string $name,
     ) {
         Assertion::positiveInt($id, 'timePeriod::id');
     }
