@@ -46,7 +46,7 @@ final class CountResourcesController extends AbstractController
      */
     public function __construct(
         private readonly ContactInterface $contact,
-        private readonly RequestValidator $validator
+        private readonly RequestValidator $validator,
     ) {
     }
 
