@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import { initializeConfigAclAndGetLoginPage } from '../common';
 
 before(() => {
@@ -27,7 +26,11 @@ beforeEach(() => {
 Given('an administrator is logged in the platform', () => {
   cy.loginByTypeOfUser({ jsonName: 'admin', loginViaApi: true })
     .wait('@getLastestUserFilters')
-    .visit(PAGES.configuration.centreonUiLegacy)
+    .navigateTo({
+      page: 'Centreon UI',
+      rootItemNumber: 4,
+      subMenu: 'Parameters'
+    })
     .wait('@getTimeZone');
 });
 
@@ -50,7 +53,7 @@ Then(
   () => {
     cy.isInProfileMenu('Edit profile').click();
 
-    cy.visit(PAGES.configuration.accountParametersLegacy)
+    cy.visit('/centreon/main.php?p=50104&o=c')
       .wait('@getTimeZone')
       .getIframeBody()
       .find('form #tab1')
@@ -59,7 +62,11 @@ Then(
         cy.get('#aKey').invoke('val').should('not.be.undefined');
       });
 
-    cy.visit(PAGES.configuration.contactsUsersLegacy)
+    cy.navigateTo({
+      page: 'Contacts / Users',
+      rootItemNumber: 3,
+      subMenu: 'Users'
+    })
       .reload()
       .wait('@getTimeZone')
       .getIframeBody()
@@ -85,7 +92,7 @@ Given(
       loginViaApi: true
     })
       .isInProfileMenu('Edit profile')
-      .visit(PAGES.configuration.accountParametersLegacy)
+      .visit('/centreon/main.php?p=50104&o=c')
       .wait('@getTimeZone')
       .getIframeBody()
       .find('form #tab1')
@@ -126,7 +133,11 @@ Given('a user with an autologin key generated', () => {
 });
 
 When('a user generates an autologin link', () => {
-  cy.visit(PAGES.configuration.hostsTemplatesLegacy)
+  cy.navigateTo({
+    page: 'Templates',
+    rootItemNumber: 2,
+    subMenu: 'Hosts'
+  })
     .wait('@getTimeZone')
     .getIframeBody()
     .find('form')
@@ -152,7 +163,7 @@ Given(
       jsonName: 'user',
       loginViaApi: true
     });
-    cy.visit(PAGES.configuration.accountParametersLegacy)
+    cy.visit('/centreon/main.php?p=50104&o=c')
       .wait('@getTimeZone')
       .isInProfileMenu('Copy autologin link')
       .get('#autologin-input')
