@@ -1,14 +1,14 @@
-import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
+import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
 import {
   checkHostsAreMonitored,
-  checkServicesAreMonitored,
-  checkMetricsAreMonitored
+  checkMetricsAreMonitored,
+  checkServicesAreMonitored
 } from '../../../commons';
-import dashboardAdministratorUser from '../../../fixtures/users/user-dashboard-administrator.json';
 import dashboards from '../../../fixtures/dashboards/creation/dashboards.json';
 import resourceTable from '../../../fixtures/dashboards/creation/widgets/dashboardWithResourceTableWidget.json';
 import genericTextWidgets from '../../../fixtures/dashboards/creation/widgets/genericText.json';
+import dashboardAdministratorUser from '../../../fixtures/users/user-dashboard-administrator.json';
 
 const services = {
   serviceCritical: {
@@ -130,7 +130,7 @@ before(() => {
 
   ['Disk-/', 'Load', 'Memory', 'Ping'].forEach((service) => {
     cy.scheduleServiceCheck({ host: 'Centreon-Server', service });
-  })
+  });
 
   checkHostsAreMonitored([
     { name: services.serviceOk.host },
@@ -167,11 +167,11 @@ beforeEach(() => {
   }).as('listAllDashboards');
   cy.intercept({
     method: 'POST',
-    url: `/centreon/api/latest/configuration/dashboards/*/access_rights/contacts`
+    url: '/centreon/api/latest/configuration/dashboards/*/access_rights/contacts'
   }).as('addContactToDashboardShareList');
   cy.intercept({
     method: 'PATCH',
-    url: `/centreon/api/latest/configuration/dashboards/*`
+    url: '/centreon/api/latest/configuration/dashboards/*'
   }).as('updateDashboard');
   cy.intercept({
     method: 'GET',
@@ -211,7 +211,12 @@ after(() => {
 });
 
 Given('a dashboard that includes a configured resource table widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
@@ -235,7 +240,7 @@ Then('only the hosts must be displayed', () => {
     () =>
       cy
         .get(
-          `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+          '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
         )
         .should('be.visible')
         .invoke('text')
@@ -263,7 +268,7 @@ Then('only the services must be displayed', () => {
     () =>
       cy
         .get(
-          `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+          '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
         )
         .should('be.visible')
         .invoke('text')
@@ -282,7 +287,12 @@ Then('only the services must be displayed', () => {
 });
 
 Given('a dashboard containing a configured resource table widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.editWidget(1);
   cy.wait('@resourceRequest');
@@ -303,7 +313,7 @@ Then(
       () =>
         cy
           .get(
-            `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+            '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
           )
           .should('be.visible')
           .invoke('text')
@@ -327,6 +337,9 @@ When(
   () => {
     cy.contains('Select all').click();
     cy.wait('@resourceRequest');
+    cy.getByLabel({ label: 'RichTextEditor' })
+      .eq(0)
+      .type(genericTextWidgets.default.description, { force: true });
   }
 );
 
@@ -336,8 +349,8 @@ Then(
     cy.getCellContent(1, 2).then((myTableContent) => {
       expect(myTableContent[1]).to.include('Critical');
       expect(myTableContent[2]).to.include('Warning');
-      expect(myTableContent[3]).to.include('Unknown');
-      expect(myTableContent[6]).to.include('Pending');
+      expect(myTableContent[3]).to.match(/Pending|Unknown/);
+      expect(myTableContent[6]).to.match(/Pending|Unknown/);
     });
   }
 );
@@ -349,7 +362,7 @@ Then(
       () =>
         cy
           .get(
-            `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+            '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
           )
           .should('be.visible')
           .invoke('text')
@@ -369,11 +382,17 @@ Then(
 );
 
 Given('a dashboard featuring two resource table widgets', () => {
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithDoubleWidget(
+    dashboards.default,
+    resourceTable,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
-  cy.getByTestId({ testId: 'MoreHorizIcon' }).click();
-  cy.getByTestId({ testId: 'ContentCopyIcon' }).click();
+  cy.getByTestId({ testId: 'More actions' }).click();
+  cy.getByTestId({ testId: 'Duplicate' }).click();
 });
 
 When('the dashboard administrator user deletes one of the widgets', () => {
@@ -386,7 +405,7 @@ Then('only the contents of the other widget are displayed', () => {
     () =>
       cy
         .get(
-          `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+          '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
         )
         .should('exist')
         .invoke('text')
@@ -403,7 +422,12 @@ Then('only the contents of the other widget are displayed', () => {
 });
 
 Given('a dashboard having a configured resource table widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
 });
@@ -411,8 +435,8 @@ Given('a dashboard having a configured resource table widget', () => {
 When(
   'the dashboard administrator user duplicates the resource table widget',
   () => {
-    cy.getByTestId({ testId: 'MoreHorizIcon' }).click();
-    cy.getByTestId({ testId: 'ContentCopyIcon' }).click();
+    cy.getByTestId({ testId: 'More actions' }).click();
+    cy.getByTestId({ testId: 'Duplicate' }).click();
   }
 );
 
@@ -423,7 +447,7 @@ Then(
       () =>
         cy
           .get(
-            `.MuiTable-root:eq(1) .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+            '.MuiTable-root:eq(1) .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
           )
           .should('exist')
           .invoke('text')
@@ -454,7 +478,7 @@ When(
   'the dashboard administrator user selects the option to add a new widget',
   () => {
     cy.getByTestId({ testId: 'edit_dashboard' }).click();
-    cy.getByTestId({ testId: 'AddIcon' }).click();
+    cy.contains('div[class*="-addWidgetPanel"] h5', 'Add a widget').click();
   }
 );
 
@@ -511,7 +535,7 @@ Then("the resource table widget is added to the dashboard's layout", () => {
     () =>
       cy
         .get(
-          `.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)`
+          '.MuiTable-root .MuiTableRow-root:nth-child(1) .MuiTableCell-root:nth-child(2)'
         )
         .should('be.visible')
         .invoke('text')
@@ -530,7 +554,12 @@ Then("the resource table widget is added to the dashboard's layout", () => {
 });
 
 Given('a dashboard with a resource table widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
@@ -553,75 +582,87 @@ Then(
 );
 
 Given('a dashboard containing a resource table widget', () => {
-  cy.logoutViaAPI()
+  cy.logoutViaAPI();
   cy.loginByTypeOfUser({
     jsonName: 'admin',
     loginViaApi: false
   });
-  cy.insertDashboardWithWidget(dashboards.default, resourceTable);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    resourceTable,
+    'centreon-widget-resourcestable',
+    '/widgets/resourcestable'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
   cy.wait('@resourceRequest');
 });
 
-When('the dashboard administrator clicks on a random resource from the resource table', () => {
-  cy.get('[aria-label^="Select row"]').eq(0).click({force:true})
-});
+When(
+  'the dashboard administrator clicks on a random resource from the resource table',
+  () => {
+    cy.get('[aria-label^="Select row"]').eq(0).click({ force: true });
+  }
+);
 
-Then('the dashboard administrator clicks on the downtime button and submits', () => {
-  cy.getByLabel({ label: 'Set downtime' }).eq(1).click()
-  cy.contains('Set downtime').realClick()
-  cy.wait('@setDowntime')
-});
+Then(
+  'the dashboard administrator clicks on the downtime button and submits',
+  () => {
+    cy.getByLabel({ label: 'Set downtime' }).eq(1).click();
+    cy.contains('Set downtime').realClick();
+    cy.wait('@setDowntime');
+  }
+);
 
 Then('the dashboard administrator clicks on the downtime filter', () => {
   cy.get('input[name="unhandled_problems"]').click();
   cy.get('input[name="in_downtime"]').click();
 });
 
-Then('the resources set to downtime should be displayed', () => {
-  cy.waitUntil(() =>
-    cy.get('body').then($body => {
-      const element = $body.find('svg[data-icon="Downtime"]');
-      return element.length > 0 && element.is(':visible');
-    })
-  , {
-    errorMsg: 'The element is not visible',
-    timeout: 50000,
-    interval: 2000
-  }).then((isVisible) => {
+Then('the resources set to in downtime should be displayed', () => {
+  cy.waitUntil(
+    () =>
+      cy.get('body').then(($body) => {
+        const element = $body.find('svg[data-icon="Downtime"]');
+
+        return element.length > 0 && element.is(':visible');
+      }),
+    {
+      errorMsg: 'The element is not visible',
+      interval: 2000,
+      timeout: 50000
+    }
+  ).then((isVisible) => {
     if (!isVisible) {
       throw new Error('The element is not visible');
     }
   });
 });
 
-Then('the dashboard administrator clicks on the acknowledge button and submits', () => {
-  cy.getByTestId({ testId: 'mainAcknowledge' }).eq(1).click({force:true});
-  cy.getByTestId({ testId: 'Confirm' }).eq(1).click();
-  cy.wait('@setAcknowledge')
-});
+Then(
+  'the dashboard administrator clicks on the acknowledge button and submits',
+  () => {
+    cy.getByTestId({ testId: 'mainAcknowledge' }).eq(1).click({ force: true });
+    cy.getByTestId({ testId: 'Confirm' }).eq(1).click();
+    cy.wait('@setAcknowledge');
+  }
+);
 
 Then('the dashboard administrator clicks on the acknowledge filter', () => {
-  cy.get('input[name="undefined"]').click();
-  cy.get('input[name="warning"]').click();
-  cy.get('input[name="acknowledged"]').click();
+  cy.get('input[name="unhandled_problems"]').click();
 });
 
-Then('the resources set to acknowledge should be displayed', () => {
-  cy.waitUntil(() =>
-    cy.get('body').then($body => {
-      const element = $body.find('[aria-label="service2 Acknowledged"]');
-      return element.length > 0 && element.is(':visible');
-    })
-  , {
+Then('the resources set to acknowledged should be displayed', () => {
+  cy.waitUntil(() => cy.get('body').contains('service3'), {
     errorMsg: 'The element with label "service3 Acknowledged" is not visible',
-    timeout: 50000,
-    interval: 2000
+    interval: 2000,
+    timeout: 50000
   }).then((isVisible) => {
     if (!isVisible) {
-      throw new Error('The element with label "service3 Acknowledged" is not visible');
+      throw new Error(
+        'The element with label "service2 Acknowledged" is not visible'
+      );
     }
   });
 });
