@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import {
   checkMetricsAreMonitored,
   checkServicesAreMonitored
@@ -173,7 +172,7 @@ Given('a saved critical service filter', () => {
     setUserFilter(filters)
   );
 
-  cy.visit(PAGES.monitoring.resourcesStatus).wait([
+  cy.visit('centreon/monitoring/resources').wait([
     '@getFilters',
     '@monitoringEndpoint'
   ]);
@@ -187,7 +186,7 @@ Given('a saved critical service filter', () => {
 
 When('I select the critical service filter', () => {
   cy.contains('Critical_Services').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then('only the critical services are displayed in the result', () => {
@@ -201,7 +200,7 @@ Given('a saved pending host filter', () => {
     setUserFilter(filters)
   );
 
-  cy.visit(PAGES.monitoring.resourcesStatus).wait([
+  cy.visit('centreon/monitoring/resources').wait([
     '@getFilters',
     '@monitoringEndpoint'
   ]);
@@ -215,7 +214,7 @@ Given('a saved pending host filter', () => {
 
 When('I select the pending host filter', () => {
   cy.contains('Pending_Hosts').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then('only the pending hosts are displayed in the result', () => {
@@ -229,7 +228,7 @@ Given('a saved up host filter', () => {
     setUserFilter(filters)
   );
 
-  cy.visit(PAGES.monitoring.resourcesStatus).wait([
+  cy.visit('centreon/monitoring/resources').wait([
     '@getFilters',
     '@monitoringEndpoint'
   ]);
@@ -243,7 +242,7 @@ Given('a saved up host filter', () => {
 
 When('I select the up host filter', () => {
   cy.contains('Up_Hosts').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then('only the up hosts are displayed in the result', () => {
@@ -259,7 +258,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -274,7 +273,7 @@ Given(
 
 When('I select host group filter with all service statuses', () => {
   cy.contains('HostGroupAndServices').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then(
@@ -285,12 +284,13 @@ Then(
         cy.get('div[class*="statusColumn"]:first')
           .invoke('text')
           .should((text) => {
-            expect(text.trim()).to.match(/Pending|Unknown/);
+            expect(text.trim()).to.match(/Pending|Unknown|Warning/);
           });
       }
     );
-    cy.get('div[class*="statusColumn"]').each(($statusCell, _index) => {
+    cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
 
       expect(cellText).to.match(/^(Pending|OK|Unknown)$/);
     });
@@ -304,7 +304,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -319,7 +319,7 @@ Given(
 
 When('I select the host group filter with OK and Up statuses', () => {
   cy.contains('HostGroupWithUpOkStatuses').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then('only services with OK and Up statuses are shown in the result', () => {
@@ -332,6 +332,7 @@ Then('only services with OK and Up statuses are shown in the result', () => {
   });
   cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
     const cellText = $statusCell.text().trim();
+    cy.log(`Cell ${index}: ${cellText}`);
     expect(['OK', 'Up']).to.include(
       cellText,
       `Cell ${index} has unexpected text: ${cellText}`
@@ -344,7 +345,7 @@ Given('a saved filter that includes Up hosts and Critical services', () => {
     setUserFilter(filters)
   );
 
-  cy.visit(PAGES.monitoring.resourcesStatus).wait([
+  cy.visit('centreon/monitoring/resources').wait([
     '@getFilters',
     '@monitoringEndpoint'
   ]);
@@ -358,7 +359,7 @@ Given('a saved filter that includes Up hosts and Critical services', () => {
 
 When('I select the Up hosts and Critical services filter', () => {
   cy.contains('upHostAndCriticalServiceFilter').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then(
@@ -369,6 +370,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['Critical', 'Up']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -384,7 +386,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -399,7 +401,7 @@ Given(
 
 When('I select the filter for the host monitoring server and OK status', () => {
   cy.contains('hostMonitoringServerOkStatus').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then(
@@ -412,6 +414,7 @@ Then(
     );
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['OK']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -425,7 +428,7 @@ Given('a saved filter that includes a monitoring server with OK status', () => {
     setUserFilter(filters)
   );
 
-  cy.visit(PAGES.monitoring.resourcesStatus).wait([
+  cy.visit('centreon/monitoring/resources').wait([
     '@getFilters',
     '@monitoringEndpoint'
   ]);
@@ -439,7 +442,7 @@ Given('a saved filter that includes a monitoring server with OK status', () => {
 
 When('I select the filter for the monitoring server with OK status', () => {
   cy.contains('monitoringServerAndOkStatus').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then(
@@ -452,6 +455,7 @@ Then(
     );
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['OK']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -467,7 +471,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -482,7 +486,7 @@ Given(
 
 When('I select the filter for services with OK and Critical statuses', () => {
   cy.contains('criticalAndOkServicesFilter').click();
-  cy.getByTestId({ testId: 'RefreshIcon' }).click();
+  cy.get('[aria-label="Refresh"]').click();
 });
 
 Then(
@@ -493,6 +497,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['Critical', 'OK']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -508,7 +513,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -525,7 +530,7 @@ When(
   'I apply the filter for acknowledged services with all states selected',
   () => {
     cy.contains('acknowledgeServiceAllStates').click();
-    cy.getByTestId({ testId: 'RefreshIcon' }).click();
+    cy.get('[aria-label="Refresh"]').click();
   }
 );
 
@@ -540,6 +545,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['Critical']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -555,7 +561,7 @@ Given(
       (filters) => setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -572,7 +578,7 @@ When(
   'I apply the filter for services with status OK and service category ping',
   () => {
     cy.contains('OkServiceAndPingServiceCategory').click();
-    cy.getByTestId({ testId: 'RefreshIcon' }).click();
+    cy.get('[aria-label="Refresh"]').click();
   }
 );
 
@@ -584,6 +590,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['OK']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -599,7 +606,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -616,7 +623,7 @@ When(
   'I apply the filter for services with statuses OK and Critical and status types Hard and Soft',
   () => {
     cy.contains('hardSoftStatusFilter').click();
-    cy.getByTestId({ testId: 'RefreshIcon' }).click();
+    cy.get('[aria-label="Refresh"]').click();
   }
 );
 
@@ -628,6 +635,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['OK', 'Critical']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
@@ -643,7 +651,7 @@ Given(
       setUserFilter(filters)
     );
 
-    cy.visit(PAGES.monitoring.resourcesStatus).wait([
+    cy.visit('centreon/monitoring/resources').wait([
       '@getFilters',
       '@monitoringEndpoint'
     ]);
@@ -660,7 +668,7 @@ When(
   'I apply the filter for the selected host service and service category',
   () => {
     cy.contains('hostServiceServiceCategory').click();
-    cy.getByTestId({ testId: 'RefreshIcon' }).click();
+    cy.get('[aria-label="Refresh"]').click();
   }
 );
 
@@ -672,6 +680,7 @@ Then(
     });
     cy.get('div[class*="statusColumn"]').each(($statusCell, index) => {
       const cellText = $statusCell.text().trim();
+      cy.log(`Cell ${index}: ${cellText}`);
       expect(['OK']).to.include(
         cellText,
         `Cell ${index} has unexpected text: ${cellText}`
