@@ -1,3 +1,108 @@
+interface Dependency {
+  name: string;
+  description: string;
+  parentRelationship: number;
+  executionFailsOnOk: number;
+  executionFailsOnWarning: number;
+  executionFailsOnUnknown: number;
+  executionFailsOnCritical: number;
+  executionFailsOnPending: number;
+  executionFailsOnNone: number;
+  notificationFailsOnNone: number;
+  notificationFailsOnOk: number;
+  notificationFailsOnWarning: number;
+  notificationFailsOnUnknown: number;
+  notificationFailsOnCritical: number;
+  notificationFailsOnPending: number;
+  comment: string;
+}
+
+interface ServiceDependency {
+  dependency: Dependency;
+  services: string[];
+  dependentServices: string[];
+  dependentHosts: string[];
+}
+
+interface ServiceGroupDependency {
+  dependency: Dependency;
+  serviceGroups: string[];
+  dependentServiceGroups: string[];
+}
+
+interface VirtualMetric {
+  name: string;
+  linkedHostServices: string;
+  knownMetric: string;
+  unit: string;
+  warningThreshold: string;
+  criticalThreshold: string;
+  comments: string;
+}
+
+interface MetaService {
+  name: string;
+  maxCheckAttempts: string;
+}
+
+interface MetaServiceDependency {
+  name: string;
+  description: string;
+  parentRelationship: number;
+  executionFailsOnOk: number;
+  executionFailsOnWarning: number;
+  executionFailsOnUnknown: number;
+  executionFailsOnCritical: number;
+  executionFailsOnPending: number;
+  executionFailsOnNone: number;
+  notificationFailsOnNone: number;
+  notificationFailsOnOk: number;
+  notificationFailsOnWarning: number;
+  notificationFailsOnUnknown: number;
+  notificationFailsOnCritical: number;
+  notificationFailsOnPending: number;
+  metaServicesNames: string[];
+  dependentMetaServicesNames: string[];
+  comment: string;
+}
+
+interface HostGroupService {
+  name: string;
+  hostGroups: string;
+  template: string;
+  checkCommand: string;
+  macroName: string;
+  macroValue: number;
+  checkPeriod: string;
+  maxCheckAttempts: number;
+  normalCheckInterval: number;
+  retryCheckInterval: number;
+  contacts: string;
+  contactGroups: string;
+  notificationInterval: number;
+  notificationPeriod: string;
+  firstNotificationDelay: number;
+  recoveryNotificationDelay: number;
+  serviceGroups: string;
+  serviceTrap: string;
+  freshnessThreshold: number;
+  serviceCategories: string;
+  noteUrl: string;
+  note: string;
+  actionUrl: string;
+  atlIcon: string;
+  geoCoords: string;
+  geoCoordsTruncated: string;
+  comment: string;
+}
+
+interface HtmlElt {
+  tag: string;
+  attribut: string;
+  attributValue: string;
+  valueOrIndex: string;
+}
+
 Cypress.Commands.add(
   'addOrUpdateVirtualMetric',
   (body: VirtualMetric, showGraph: boolean) => {
@@ -50,11 +155,11 @@ Cypress.Commands.add(
     cy.getIframeBody()
       .find('input[name="warn"]')
       .clear()
-      .type(body.warning_threshold);
+      .type(body.warningThreshold);
     cy.getIframeBody()
       .find('input[name="crit"]')
       .clear()
-      .type(body.critical_threshold);
+      .type(body.criticalThreshold);
     if (!showGraph) {
       cy.getIframeBody()
         .find('div.md-checkbox.md-checkbox-inline')
@@ -92,10 +197,10 @@ Cypress.Commands.add('checkFieldsOfVm', (body: VirtualMetric) => {
     .should('have.value', body.unit);
   cy.getIframeBody()
     .find('input[name="warn"]')
-    .should('have.value', body.warning_threshold);
+    .should('have.value', body.warningThreshold);
   cy.getIframeBody()
     .find('input[name="crit"]')
-    .should('have.value', body.critical_threshold);
+    .should('have.value', body.criticalThreshold);
   cy.getIframeBody()
     .find('textarea[name="comment"]')
     .should('have.value', body.comments);
@@ -108,53 +213,90 @@ Cypress.Commands.add('addMetaService', (body: MetaService) => {
   cy.getIframeBody().find('input[name="meta_name"]').type(body.name);
   cy.getIframeBody()
     .find('input[name="max_check_attempts"]')
-    .type(body.max_check_attempts);
+    .type(body.maxCheckAttempts);
   cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(0).click();
   cy.wait('@getTimeZone');
 });
 
-Cypress.Commands.add('addMsDependency', (body: MetaServiceDependency) => {
-  cy.waitForElementInIframe('#main-content', 'input[name="dep_name"]');
-  cy.getIframeBody().find('input[name="dep_name"]').type(body.name);
-  cy.getIframeBody()
-    .find('input[name="dep_description"]')
-    .type(body.description);
-  cy.getIframeBody().find('label[for="eUnknown"]').click({ force: true });
-  cy.getIframeBody().find('label[for="nUnknown"]').click({ force: true });
-  cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
-  cy.getIframeBody().find(`div[title="${body.metaServicesNames[0]}"]`).click();
-  cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
-  cy.getIframeBody().find(`div[title="${body.metaServicesNames[1]}"]`).click();
-  cy.getIframeBody().find('input[class="select2-search__field"]').eq(1).click();
-  cy.getIframeBody().find(`div[title="${body.dependentMSNames[0]}"]`).click();
-  cy.getIframeBody().find('textarea[name="dep_comment"]').type(body.comment);
-  cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(0).click();
-});
+Cypress.Commands.add(
+  'addMetaserviceDependency',
+  (body: MetaServiceDependency) => {
+    cy.waitForElementInIframe('#main-content', 'input[name="dep_name"]');
+    cy.getIframeBody().find('input[name="dep_name"]').type(body.name);
+    cy.getIframeBody()
+      .find('input[name="dep_description"]')
+      .type(body.description);
+    cy.getIframeBody().find('label[for="eUnknown"]').click({ force: true });
+    cy.getIframeBody().find('label[for="nUnknown"]').click({ force: true });
+    cy.getIframeBody()
+      .find('input[class="select2-search__field"]')
+      .eq(0)
+      .click();
+    cy.getIframeBody()
+      .find(`div[title="${body.metaServicesNames[0]}"]`)
+      .click();
+    cy.getIframeBody()
+      .find('input[class="select2-search__field"]')
+      .eq(0)
+      .click();
+    cy.getIframeBody()
+      .find(`div[title="${body.metaServicesNames[1]}"]`)
+      .click();
+    cy.getIframeBody()
+      .find('input[class="select2-search__field"]')
+      .eq(1)
+      .click();
+    cy.getIframeBody()
+      .find(`div[title="${body.dependentMetaServicesNames[0]}"]`)
+      .click();
+    cy.getIframeBody().find('textarea[name="dep_comment"]').type(body.comment);
+    cy.getIframeBody()
+      .find('input.btc.bt_success[name^="submit"]')
+      .eq(0)
+      .click();
+  }
+);
 
-Cypress.Commands.add('updateMsDependency', (body: MetaServiceDependency) => {
-  cy.waitForElementInIframe('#main-content', 'input[name="dep_name"]');
-  cy.getIframeBody().find('input[name="dep_name"]').clear().type(body.name);
-  cy.getIframeBody()
-    .find('input[name="dep_description"]')
-    .clear()
-    .type(body.description);
-  cy.getIframeBody().find('label[for="eUnknown"]').click({ force: true });
-  cy.getIframeBody().find('label[for="eOk"]').click({ force: true });
+Cypress.Commands.add(
+  'updateMetaserviceDependency',
+  (body: MetaServiceDependency) => {
+    cy.waitForElementInIframe('#main-content', 'input[name="dep_name"]');
+    cy.getIframeBody().find('input[name="dep_name"]').clear().type(body.name);
+    cy.getIframeBody()
+      .find('input[name="dep_description"]')
+      .clear()
+      .type(body.description);
+    cy.getIframeBody().find('label[for="eUnknown"]').click({ force: true });
+    cy.getIframeBody().find('label[for="eOk"]').click({ force: true });
 
-  cy.getIframeBody().find('label[for="nUnknown"]').click({ force: true });
-  cy.getIframeBody().find('label[for="nCritical"]').click({ force: true });
-  cy.getIframeBody().find('span[title="Clear field"]').eq(0).click();
-  cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
-  cy.getIframeBody().find(`div[title="${body.metaServicesNames[0]}"]`).click();
-  cy.getIframeBody().find('span[title="Clear field"]').eq(1).click();
-  cy.getIframeBody().find('input[class="select2-search__field"]').eq(1).click();
-  cy.getIframeBody().find(`div[title="${body.dependentMSNames[0]}"]`).click();
-  cy.getIframeBody()
-    .find('textarea[name="dep_comment"]')
-    .clear()
-    .type(body.comment);
-  cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(0).click();
-});
+    cy.getIframeBody().find('label[for="nUnknown"]').click({ force: true });
+    cy.getIframeBody().find('label[for="nCritical"]').click({ force: true });
+    cy.getIframeBody().find('span[title="Clear field"]').eq(0).click();
+    cy.getIframeBody()
+      .find('input[class="select2-search__field"]')
+      .eq(0)
+      .click();
+    cy.getIframeBody()
+      .find(`div[title="${body.metaServicesNames[0]}"]`)
+      .click();
+    cy.getIframeBody().find('span[title="Clear field"]').eq(1).click();
+    cy.getIframeBody()
+      .find('input[class="select2-search__field"]')
+      .eq(1)
+      .click();
+    cy.getIframeBody()
+      .find(`div[title="${body.dependentMetaServicesNames[0]}"]`)
+      .click();
+    cy.getIframeBody()
+      .find('textarea[name="dep_comment"]')
+      .clear()
+      .type(body.comment);
+    cy.getIframeBody()
+      .find('input.btc.bt_success[name^="submit"]')
+      .eq(0)
+      .click();
+  }
+);
 
 Cypress.Commands.add('addCommonDependencyFields', (body: Dependency) => {
   cy.waitForElementInIframe('#main-content', 'input[name="dep_name"]');
@@ -236,13 +378,13 @@ Cypress.Commands.add(
       .find('input[class="select2-search__field"]')
       .eq(0)
       .click();
-    cy.getIframeBody().find(`div[title="${body.service_groups[0]}"]`).click();
+    cy.getIframeBody().find(`div[title="${body.serviceGroups[0]}"]`).click();
     cy.getIframeBody()
       .find('input[class="select2-search__field"]')
       .eq(1)
-      .type(body.dependent_service_groups[0]);
+      .type(body.dependentServiceGroups[0]);
     cy.getIframeBody()
-      .find(`div[title="${body.dependent_service_groups[0]}"]`)
+      .find(`div[title="${body.dependentServiceGroups[0]}"]`)
       .click();
     cy.getIframeBody()
       .find('input.btc.bt_success[name^="submit"]')
@@ -262,14 +404,14 @@ Cypress.Commands.add(
       .find('input[class="select2-search__field"]')
       .eq(0)
       .click();
-    cy.getIframeBody().find(`div[title="${body.service_groups[0]}"]`).click();
+    cy.getIframeBody().find(`div[title="${body.serviceGroups[0]}"]`).click();
     cy.getIframeBody().find('span[title="Clear field"]').eq(1).click();
     cy.getIframeBody()
       .find('input[class="select2-search__field"]')
       .eq(1)
-      .type(body.dependent_service_groups[0]);
+      .type(body.dependentServiceGroups[0]);
     cy.getIframeBody()
-      .find(`div[title="${body.dependent_service_groups[0]}"]`)
+      .find(`div[title="${body.dependentServiceGroups[0]}"]`)
       .click();
     cy.getIframeBody()
       .find('input.btc.bt_success[name^="submit"]')
@@ -301,12 +443,12 @@ Cypress.Commands.add(
     cy.getIframeBody()
       .find('input[class="select2-search__field"]')
       .eq(6)
-      .type(body.checkcommand);
+      .type(body.checkCommand);
     cy.clickOnFieldInIframe(htmldata[7]);
     cy.getIframeBody().find('#macro_add').click();
     cy.waitForElementInIframe('#main-content', '#macroInput_0');
-    cy.getIframeBody().find('#macroInput_0').clear().type(body.macroname);
-    cy.getIframeBody().find('#macroValue_0').clear().type(`${body.macrovalue}`);
+    cy.getIframeBody().find('#macroInput_0').clear().type(body.macroName);
+    cy.getIframeBody().find('#macroValue_0').clear().type(`${body.macroValue}`);
     cy.clickOnFieldInIframe(htmldata[8]);
     cy.getIframeBody().find('#select2-timeperiod_tp_id-container').click();
     cy.clickOnFieldInIframe(htmldata[9]);
@@ -402,7 +544,7 @@ Cypress.Commands.add(
       .find('#service_hgPars')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.hostgroups);
+      .and('have.text', body.hostGroups);
     cy.getIframeBody()
       .find('#service_template_model_stm_id')
       .find('option:selected')
@@ -412,27 +554,27 @@ Cypress.Commands.add(
       .find('#command_command_id')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.checkcommand);
+      .and('have.text', body.checkCommand);
     cy.getIframeBody()
       .find('#macroInput_0')
-      .should('have.value', body.macroname);
+      .should('have.value', body.macroName);
     cy.getIframeBody()
       .find('#macroValue_0')
-      .should('have.value', body.macrovalue);
+      .should('have.value', body.macroValue);
     cy.getIframeBody()
       .find('#timeperiod_tp_id')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.checkperiod);
+      .and('have.text', body.checkPeriod);
     cy.getIframeBody()
       .find('input[name="service_max_check_attempts"]')
-      .should('have.value', body.maxcheckattempts);
+      .should('have.value', body.maxCheckAttempts);
     cy.getIframeBody()
       .find('input[name="service_normal_check_interval"]')
-      .should('have.value', body.normalcheckinterval);
+      .should('have.value', body.normalCheckInterval);
     cy.getIframeBody()
       .find('input[name="service_retry_check_interval"]')
-      .should('have.value', body.retrycheckinterval);
+      .should('have.value', body.retryCheckInterval);
     cy.checkLegacyRadioButton('No');
     //Notifications
     cy.getIframeBody().contains('a', 'Notifications').click();
@@ -446,24 +588,24 @@ Cypress.Commands.add(
       .find('#service_cgs')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.contactgroups);
+      .and('have.text', body.contactGroups);
 
     cy.getIframeBody()
       .find('input[name="service_notification_interval"]')
-      .should('have.value', body.notinterval);
+      .should('have.value', body.notificationInterval);
     cy.getIframeBody()
       .find('#timeperiod_tp_id2')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.notificationperiod);
+      .and('have.text', body.notificationPeriod);
     cy.getIframeBody().find('#notifC').should('be.checked');
     cy.getIframeBody().find('#notifU').should('be.checked');
     cy.getIframeBody()
       .find('input[name="service_first_notification_delay"]')
-      .should('have.value', body.firstnotdelay);
+      .should('have.value', body.firstNotificationDelay);
     cy.getIframeBody()
       .find('input[name="service_recovery_notification_delay"]')
-      .should('have.value', body.recoverynotdelay);
+      .should('have.value', body.recoveryNotificationDelay);
     //Relations
     cy.getIframeBody().contains('a', 'Relations').click();
     cy.get('body').click(0, 0);
@@ -471,18 +613,18 @@ Cypress.Commands.add(
       .find('#service_sgs')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.servicegroups);
+      .and('have.text', body.serviceGroups);
     cy.getIframeBody()
       .find('#service_traps')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.servicetrap);
+      .and('have.text', body.serviceTrap);
     //Data Processing
     cy.getIframeBody().contains('a', 'Data Processing').click();
     cy.get('body').click(0, 0);
     cy.getIframeBody()
       .find('input[name="service_freshness_threshold"]')
-      .should('have.value', body.freshnessthreshold);
+      .should('have.value', body.freshnessThreshold);
     //Extended Info
     cy.getIframeBody().contains('a', 'Extended Info').click();
     cy.get('body').click(0, 0);
@@ -490,21 +632,21 @@ Cypress.Commands.add(
       .find('#service_categories')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.servicecategories);
+      .and('have.text', body.serviceCategories);
 
     cy.getIframeBody()
       .find('input[name="esi_notes_url"]')
-      .should('have.value', body.noteurl);
+      .should('have.value', body.noteUrl);
     cy.getIframeBody()
       .find('input[name="esi_notes"]')
       .should('have.value', body.note);
     cy.getIframeBody()
       .find('input[name="esi_action_url"]')
-      .should('have.value', body.actionurl);
+      .should('have.value', body.actionUrl);
     cy.getIframeBody().find('#esi_icon_image').should('have.value', '1');
     cy.getIframeBody()
       .find('input[name="esi_icon_image_alt"]')
-      .should('have.value', body.atlicon);
+      .should('have.value', body.atlIcon);
     cy.getIframeBody()
       .find('input[name="geo_coords"]')
       .should('have.value', body.geoCoordsTruncated);
@@ -514,143 +656,6 @@ Cypress.Commands.add(
   }
 );
 
-interface Dependency {
-  name: string;
-  description: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  parent_relationship: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_ok: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_warning: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_unknown: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_critical: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_pending: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_none: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_none: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_ok: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_warning: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_unknown: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_critical: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_pending: number;
-  comment: string;
-}
-
-interface ServiceDependency {
-  dependency: Dependency;
-  services: string[];
-  dependentServices: string[];
-  dependentHosts: string[];
-}
-
-interface ServiceGroupDependency {
-  dependency: Dependency;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  service_groups: string[];
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  dependent_service_groups: string[];
-}
-
-interface VirtualMetric {
-  name: string;
-  linkedHostServices: string;
-  knownMetric: string;
-  unit: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  warning_threshold: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  critical_threshold: string;
-  comments: string;
-}
-
-interface MetaService {
-  name: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  max_check_attempts: string;
-}
-
-interface MetaServiceDependency {
-  name: string;
-  description: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  parent_relationship: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_ok: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_warning: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_unknown: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_critical: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_pending: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  execution_fails_on_none: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_none: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_ok: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_warning: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_unknown: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_critical: number;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_fails_on_pending: number;
-  metaServicesNames: string[];
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  dependentMSNames: string[];
-  comment: string;
-}
-
-interface HostGroupService {
-  name: string;
-  hostgroups: string;
-  template: string;
-  checkcommand: string;
-  macroname: string;
-  macrovalue: number;
-  checkperiod: string;
-  maxcheckattempts: number;
-  normalcheckinterval: number;
-  retrycheckinterval: number;
-  contacts: string;
-  contactgroups: string;
-  notinterval: number;
-  notificationperiod: string;
-  firstnotdelay: number;
-  recoverynotdelay: number;
-  servicegroups: string;
-  servicetrap: string;
-  freshnessthreshold: number;
-  servicecategories: string;
-  noteurl: string;
-  note: string;
-  actionurl: string;
-  atlicon: string;
-  geocoords: string;
-  geoCoordsTruncated: string;
-  comment: string;
-}
-
-interface HtmlElt {
-  tag: string;
-  attribut: string;
-  attributValue: string;
-  valueOrIndex: string;
-}
-
 declare global {
   // biome-ignore lint/style/noNamespace: <explanation>
   namespace Cypress {
@@ -661,8 +666,12 @@ declare global {
       ) => Cypress.Chainable;
       checkFieldsOfVm: (body: VirtualMetric) => Cypress.Chainable;
       addMetaService: (body: MetaService) => Cypress.Chainable;
-      addMsDependency: (body: MetaServiceDependency) => Cypress.Chainable;
-      updateMsDependency: (body: MetaServiceDependency) => Cypress.Chainable;
+      addMetaserviceDependency: (
+        body: MetaServiceDependency
+      ) => Cypress.Chainable;
+      updateMetaserviceDependency: (
+        body: MetaServiceDependency
+      ) => Cypress.Chainable;
       addServiceDependency: (body: ServiceDependency) => Cypress.Chainable;
       updateServiceDependency: (body: ServiceDependency) => Cypress.Chainable;
       addCommonDependencyFields: (body: Dependency) => Cypress.Chainable;
