@@ -1,11 +1,10 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import data from '../../../fixtures/snmp-traps/snmp-trap.json';
 import {
+  UpdateTrapsSnmpConfiguration,
   submitForm,
-  trapsSnmpConfiguration,
-  updateTrapsSnmpConfiguration
+  trapsSnmpConfiguration
 } from '../common';
 
 beforeEach(() => {
@@ -28,7 +27,11 @@ Given('a user is logged in Centreon', () => {
 When(
   'the user adds a new SNMP trap definition with an advanced matching rule',
   () => {
-    cy.visit(PAGES.configuration.snmpTrapsLegacy);
+    cy.navigateTo({
+      page: 'SNMP Traps',
+      rootItemNumber: 3,
+      subMenu: 'SNMP Traps'
+    });
     cy.waitForElementInIframe('#main-content', 'input[name="searchT"]');
     cy.getIframeBody().find('a.bt_success').contains('Add').click();
     trapsSnmpConfiguration({
@@ -99,7 +102,11 @@ When(
       name: data.snmp2.service_templates,
       template: 'generic-service'
     });
-    cy.visit(PAGES.configuration.snmpTrapsLegacy);
+    cy.navigateTo({
+      page: 'SNMP Traps',
+      rootItemNumber: 3,
+      subMenu: 'SNMP Traps'
+    });
     cy.waitForElementInIframe('#main-content', 'input[name="searchT"]');
     cy.getIframeBody().find('a.bt_success').contains('Add').click();
     trapsSnmpConfiguration({
@@ -114,7 +121,7 @@ When(
     submitForm();
     cy.waitForElementInIframe('#main-content', 'input[name="searchT"]');
     cy.getIframeBody().contains(data.snmp1.name).click();
-    updateTrapsSnmpConfiguration({
+    UpdateTrapsSnmpConfiguration({
       name: data.snmp2.name,
       vendor: data.snmp2.vendor,
       oid: data.snmp2.oid,
@@ -125,23 +132,16 @@ When(
       string: data.snmp2.rule.string,
       regexp: data.snmp2.rule.regexp,
       severity: data.snmp2.rule.status,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      special_command: data.snmp2.special_command,
+      specialCommand: data.snmp2.special_command,
       comments: data.snmp2.comments,
       serviceName: data.snmp2.serviceName,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      service_templates: data.snmp2.service_templates,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      routing_definition: data.snmp2.routing_definition,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      filter_services: data.snmp2.filter_services,
+      serviceTemplates: data.snmp2.service_templates,
+      routingDefinition: data.snmp2.routing_definition,
+      filterServices: data.snmp2.filter_services,
       timeout: data.snmp2.timeout,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      execution_interval: data.snmp2.execution_interval,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      output_transform: data.snmp2.output_transform,
-      // biome-ignore lint/style/useNamingConvention: <explanation>
-      custom_code: data.snmp2.custom_code
+      executionInterval: data.snmp2.execution_interval,
+      outputTransform: data.snmp2.output_transform,
+      customCode: data.snmp2.custom_code
     });
     cy.getIframeBody()
       .find('div#validForm')
@@ -238,7 +238,11 @@ Then('all changes are saved', () => {
 
 // Scenario: Duplicate SNMP trap definition
 When('the user has duplicated one existing SNMP trap definition', () => {
-  cy.visit(PAGES.configuration.snmpTrapsLegacy);
+  cy.navigateTo({
+    page: 'SNMP Traps',
+    rootItemNumber: 3,
+    subMenu: 'SNMP Traps'
+  });
   cy.waitForElementInIframe('#main-content', 'input[name="searchT"]');
   cy.getIframeBody().find('a.bt_success').contains('Add').click();
   trapsSnmpConfiguration({
@@ -290,7 +294,11 @@ Then('all SNMP trap properties are unchanged except the name', () => {
 
 // Scenario: Delete SNMP trap definition
 When('the user has deleted one existing SNMP trap definition', () => {
-  cy.visit(PAGES.configuration.snmpTrapsLegacy);
+  cy.navigateTo({
+    page: 'SNMP Traps',
+    rootItemNumber: 3,
+    subMenu: 'SNMP Traps'
+  });
   cy.waitForElementInIframe('#main-content', 'input[name="searchT"]');
   cy.getIframeBody().find('a.bt_success').contains('Add').click();
   trapsSnmpConfiguration({
