@@ -164,8 +164,8 @@ it('should present a FindAgentConfigurationsResponse when no errors occurred', f
         )
     );
 
-    $pollerOne = new Poller(1, 'poller_1');
-    $pollerTwo = new Poller(2, 'poller_2');
+    $pollerOne = new Poller(1, 'poller_1', true);
+    $pollerTwo = new Poller(2, 'poller_2', false);
 
     $this->user
         ->expects($this->once())
@@ -194,9 +194,9 @@ it('should present a FindAgentConfigurationsResponse when no errors occurred', f
 
     ($this->useCase)($this->presenter);
 
-    expect($this->presenter->data)
+    expect(value: $this->presenter->data)
         ->toBeInstanceOf(FindAgentConfigurationsResponse::class)
-        ->and($this->presenter->data->agentConfigurations)
+        ->and(value: $this->presenter->data->agentConfigurations)
         ->toBeArray()
         ->and($this->presenter->data->agentConfigurations[0])
         ->toBeInstanceOf(AgentConfigurationDto::class)
