@@ -1340,24 +1340,30 @@ class CentreonConfigCentreonBroker
     }
 
     /**
-     * Generate fieldtype array.
+     * Generate fieldinfos array.
      *
      * @param int $typeId The type id
-     * @return array
+     * @return array<string,array<string,{type:string,default:string|null}>|{type:string,default:string|null}>
      */
-    public function getFieldtypesWithGroup($typeId)
+    public function getFieldInfosWithGroup($typeId)
     {
-        $fieldTypes = [];
+        $fields = [];
         $block = $this->getBlockInfos($typeId);
         foreach ($block as $fieldInfos) {
-            if ($fieldInfos['group_name'] !== null) {
-                $fieldTypes[$fieldInfos['group_name']][$fieldInfos['fieldname']] = $fieldInfos['fieldtype'];
+            if (! empty($fieldInfos['group_name']) && $fieldInfos['group_name'] !== null) {
+                $fields[$fieldInfos['group_name']][$fieldInfos['fieldname']] = [
+                    'type' => $fieldInfos['fieldtype'],
+                    'default' => $fieldInfos['value'] ?? $this->getDefaults($fieldInfos['id']) ?? null,
+                ];
             } else {
-                $fieldTypes[$fieldInfos['fieldname']] = $fieldInfos['fieldtype'];
+                $fields[$fieldInfos['fieldname']] = [
+                    'type' => $fieldInfos['fieldtype'],
+                    'default' => $fieldInfos['value'] ?? $this->getDefaults($fieldInfos['id']) ?? null,
+                ];
             }
         }
 
-        return $fieldTypes;
+        return $fields;
     }
 
     /**
@@ -1768,7 +1774,7 @@ class CentreonConfigCentreonBroker
         /** @var string $blockId */
         $blockId = $inputOutput['blockId'];
         [, $typeId] = explode('_', $blockId);
-        $fieldTypes = $this->getFieldtypesWithGroup((int) $typeId);
+        $fieldTypes = $this->getFieldInfosWithGroup((int) $typeId);
 
         $payload = [
             'name' => $inputOutput['name'],
@@ -1782,9 +1788,11 @@ class CentreonConfigCentreonBroker
                     foreach ($groups as $subName => $subValue) {
                         [$groupName, $name] = explode('__', $subName);
 
-                        $fieldType = $fieldTypes[$groupName][$name];
-                        $payload['parameters'][$groupName][$index] ??= [];
-                        $this->addToPayload($payload['parameters'][$groupName][$index], $fieldType, $name, $subValue);
+                        $fieldType = $fieldTypes[$groupName][$name]['type'] ?? null;
+                        if ($fieldType !== null) {
+                            $payload['parameters'][$groupName][$index] ??= [];
+                            $this->addToPayload($payload['parameters'][$groupName][$index], $fieldType, $name, $subValue);
+                        }
                     }
                 }
             } else {
@@ -1794,9 +1802,9 @@ class CentreonConfigCentreonBroker
                     } else {
                         $name = $fieldName;
                     }
-                    $fieldType = $fieldTypes[$name] ?? null;
+                    $fieldType = $fieldTypes[$name]['type'] ?? null;
                 } else {
-                    $fieldType = $fieldTypes[$fieldName] ?? null;
+                    $fieldType = $fieldTypes[$fieldName]['type'] ?? null;
                 }
                 if ($fieldType !== null) {
                     $this->addToPayload($payload['parameters'], $fieldType, $fieldName, $fieldValue);
@@ -1804,15 +1812,16 @@ class CentreonConfigCentreonBroker
             }
         }
 
-        foreach ($fieldTypes as $name => $type) {
-            if ($type == 'multiselect') {
+        foreach ($fieldTypes as $name => $infos) {
+            if (! isset($infos['type'])) {
+                $infos['type'] = 'grouped';
+            } elseif ($infos['type'] === 'multiselect') {
                 $name = "filters_{$name}";
-            } elseif (is_array($type)) {
-                $type = 'grouped';
             }
+
             if (! array_key_exists($name, $payload['parameters'])) {
-                $payload['parameters'][$name] = match ($type) {
-                    'select', 'text', 'password', 'int', 'radio' => null,
+                $payload['parameters'][$name] = match ($infos['type']) {
+                    'select', 'text', 'password', 'int', 'radio' => $infos['default'],
                     'multiselect', 'grouped' => [],
                 };
             }
