@@ -1,33 +1,19 @@
 <?php
-/**
- * Copyright 2005-2015 Centreon
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+
+/*
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -95,12 +81,13 @@ class CentreonDowntimeBroker extends CentreonDowntime
             return false;
         }
         while ($row = $res->fetch()) {
-            if (isset($row['name2']) && $row['name2'] != "") {
+            if (isset($row['name2']) && $row['name2'] != '') {
                 $list['services'] = ['host_name' => $row['name1'], 'service_name' => $row['name2']];
-            } elseif (isset($row['name1']) && $row['name1'] != "") {
+            } elseif (isset($row['name1']) && $row['name1'] != '') {
                 $list['hosts'] = ['host_name' => $row['name1']];
             }
         }
+
         return $list;
     }
 
@@ -115,17 +102,17 @@ class CentreonDowntimeBroker extends CentreonDowntime
      */
     public function getDowntimeInternalId($oname1, $start_time, $dt_id, $oname2 = null)
     {
-        $query = "SELECT d.internal_id as internal_downtime_id
-        		  FROM downtimes d, hosts h ";
-        if (isset($oname2) && $oname2 != "") {
-            $query .= ", services s ";
+        $query = 'SELECT d.internal_id as internal_downtime_id
+        		  FROM downtimes d, hosts h ';
+        if (isset($oname2) && $oname2 != '') {
+            $query .= ', services s ';
         }
-        $query .= "WHERE d.host_id = h.host_id
-        		  AND d.start_time = " . $this->dbb->escape($start_time) . "
+        $query .= 'WHERE d.host_id = h.host_id
+        		  AND d.start_time = ' . $this->dbb->escape($start_time) . "
         		  AND d.comment_data = '[Downtime cycle #" . $dt_id . "]'
         		  AND h.name = '" . $this->dbb->escape($oname1) . "' ";
-        if (isset($oname2) && $oname2 != "") {
-            $query .= " AND h.host_id = s.host_id ";
+        if (isset($oname2) && $oname2 != '') {
+            $query .= ' AND h.host_id = s.host_id ';
             $query .= " AND s.description = '" . $this->dbb->escape($oname2) . "' ";
         }
         try {
@@ -134,6 +121,7 @@ class CentreonDowntimeBroker extends CentreonDowntime
             return false;
         }
         $row = $res->fetch();
+
         return $row['internal_downtime_id'];
     }
 
@@ -199,8 +187,8 @@ class CentreonDowntimeBroker extends CentreonDowntime
      * @param $cycle
      * @param $tomorrow
      *
-     * @return bool
      * @throws Exception
+     * @return bool
      */
     public function isSpecificDateDowntime($startDelay, $endDelay, $dayOfWeek, $cycle, $tomorrow)
     {
@@ -234,109 +222,10 @@ class CentreonDowntimeBroker extends CentreonDowntime
     }
 
     /**
-     * @param $downtimeStartTime
-     * @param $now
      * @param $delay
      *
-     * @return bool
      * @throws Exception
-     */
-    private function isTomorrow($downtimeStartTime, $now, $delay)
-    {
-        $tomorrow = false;
-
-        # startDelay must be between midnight - delay and midnight - 1 second
-        $nowTimestamp = strtotime($now->format('H:i'));
-        $midnightMoins1SecondDate = new DateTime('midnight -1seconds');
-        $midnightMoins1SecondTimestamp = strtotime($midnightMoins1SecondDate->format('H:i:s'));
-        $midnightMoinsDelayDate = new DateTime('midnight -' . $delay . 'seconds');
-        $midnightMoinsDelayTimestamp = strtotime($midnightMoinsDelayDate->format('H:i'));
-
-        $downtimeStartTimeTimestamp = strtotime($downtimeStartTime);
-
-        # YYYY-MM-DD 00:00:00
-        $midnightDate = new DateTime('midnight');
-        # 00:00
-        $midnight = $midnightDate->format('H:i');
-        $midnightTimestamp = strtotime($midnight);
-
-        # YYYY-MM-DD 00:00:10 (for 600 seconds delay)
-        $midnightPlusDelayDate = new DateTime('midnight +' . $delay . 'seconds');
-        # 00:10 (for 600 seconds delay)
-        $midnightPlusDelay = $midnightPlusDelayDate->format('H:i');
-        $midnightPlusDelayTimestamp = strtotime($midnightPlusDelay);
-
-        if ($downtimeStartTimeTimestamp >= $midnightTimestamp &&
-            $downtimeStartTimeTimestamp <= $midnightPlusDelayTimestamp &&
-            $nowTimestamp <= $midnightMoins1SecondTimestamp &&
-            $nowTimestamp >= $midnightMoinsDelayTimestamp
-        ) {
-            $tomorrow = true;
-        }
-
-        return $tomorrow;
-    }
-
-    /**
-     * @param $downtimeStart
-     * @param $delayStart
-     * @param $delayEnd
-     *
-     * @return bool
-     */
-    private function isApproachingTime($downtimeStart, $delayStart, $delayEnd)
-    {
-        $approachingTime = false;
-        if ($downtimeStart >= $delayStart && $downtimeStart <= $delayEnd) {
-            $approachingTime = true;
-        }
-
-        return $approachingTime;
-    }
-
-    /**
-     * reset timestamp at beginning of hour if we jump forward
-     * example:
-     *   - current date is 2021-03-28
-     *   - $time is 02:30
-     *   ==> return timestamp corresponding to 02:00 cause 02:30 does not exist (jump from 02:00 to 03:00)
-     *
-     * @param DateTime $datetime
-     * @param string $time time formatted as HH:mm
-     *
-     * @return int the calculated timestamp
-     */
-    private function manageWinterToSummerTimestamp(DateTime $datetime, string $time): int
-    {
-        $hour = explode(':', $time)[0];
-        if ((int)$datetime->format('H') > (int)$hour) {
-            $datetime->setTime($hour, '00');
-        }
-
-        return $datetime->getTimestamp();
-    }
-
-    /**
-     * @param Datetime $dateTime
-     *
-     * @return int
-     */
-    private function manageSummerToWinterTimestamp(DateTime $dateTime)
-    {
-        $datetimePlusOneHour = clone $dateTime;
-        $datetimePlusOneHour->sub(new DateInterval('PT1H'));
-        if ($datetimePlusOneHour->format('H:m') === $dateTime->format('H:m')) {
-            return $dateTime->getTimestamp() - 3600;
-        }
-
-        return $dateTime->getTimestamp();
-    }
-
-    /**
-     * @param $delay
-     *
      * @return array
-     * @throws Exception
      */
     public function getApproachingDowntimes($delay)
     {
@@ -344,10 +233,10 @@ class CentreonDowntimeBroker extends CentreonDowntime
 
         $downtimes = $this->getForEnabledResources();
 
-        $gmtObj = new CentreonGMT($this->db);
+        $gmtObj = new CentreonGMT();
 
         foreach ($downtimes as $downtime) {
-            /* Convert HH::mm::ss to HH:mm */
+            // Convert HH::mm::ss to HH:mm
             $downtime['dtp_start_time'] = substr(
                 $downtime['dtp_start_time'],
                 0,
@@ -370,7 +259,7 @@ class CentreonDowntimeBroker extends CentreonDowntime
                 $downtimeEndDate->add(new DateInterval('P1D'));
             }
 
-            # Check if we jump an hour
+            // Check if we jump an hour
             $startTimestamp = $this->manageWinterToSummerTimestamp($downtimeStartDate, $downtime['dtp_start_time']);
             $endTimestamp = $this->manageWinterToSummerTimestamp($downtimeEndDate, $downtime['dtp_end_time']);
 
@@ -378,12 +267,12 @@ class CentreonDowntimeBroker extends CentreonDowntime
                 continue;
             }
 
-            # Check if HH:mm time is approaching
-            if (!$this->isApproachingTime($startTimestamp, $startDelay->getTimestamp(), $endDelay->getTimestamp())) {
+            // Check if HH:mm time is approaching
+            if (! $this->isApproachingTime($startTimestamp, $startDelay->getTimestamp(), $endDelay->getTimestamp())) {
                 continue;
             }
 
-            # check backward of one hour
+            // check backward of one hour
             $startTimestamp = $this->manageSummerToWinterTimestamp($downtimeStartDate);
 
             $approaching = false;
@@ -428,8 +317,8 @@ class CentreonDowntimeBroker extends CentreonDowntime
     /**
      * @param $downtime
      *
-     * @return void
      * @throws PDOException
+     * @return void
      */
     public function insertCache($downtime): void
     {
@@ -450,8 +339,8 @@ class CentreonDowntimeBroker extends CentreonDowntime
     }
 
     /**
-     * @return void
      * @throws PDOException
+     * @return void
      */
     public function purgeCache(): void
     {
@@ -462,8 +351,8 @@ class CentreonDowntimeBroker extends CentreonDowntime
     /**
      * @param $downtime
      *
-     * @return bool
      * @throws PDOException
+     * @return bool
      */
     public function isScheduled($downtime)
     {
@@ -493,8 +382,8 @@ class CentreonDowntimeBroker extends CentreonDowntime
      * @param int $host_id The host id for command
      * @param string $cmd The command to send
      *
-     * @return void The command return code
      * @throws PDOException
+     * @return void The command return code
      */
     public function setCommand($host_id, $cmd): void
     {
@@ -515,7 +404,7 @@ class CentreonDowntimeBroker extends CentreonDowntime
             }
         }
 
-        if (!isset($cmdData[$host_id])) {
+        if (! isset($cmdData[$host_id])) {
             return;
         }
 
@@ -531,7 +420,106 @@ class CentreonDowntimeBroker extends CentreonDowntime
     {
         $remoteCommands = implode(PHP_EOL, $this->remoteCommands);
         if ($remoteCommands) {
-            file_put_contents($this->remoteCmdDir . "/" . time() . "-downtimes", $remoteCommands, FILE_APPEND);
+            file_put_contents($this->remoteCmdDir . '/' . time() . '-downtimes', $remoteCommands, FILE_APPEND);
         }
     }
+
+    /**
+     * @param $downtimeStartTime
+     * @param $now
+     * @param $delay
+     *
+     * @throws Exception
+     * @return bool
+     */
+    private function isTomorrow($downtimeStartTime, $now, $delay)
+    {
+        $tomorrow = false;
+
+        // startDelay must be between midnight - delay and midnight - 1 second
+        $nowTimestamp = strtotime($now->format('H:i'));
+        $midnightMoins1SecondDate = new DateTime('midnight -1seconds');
+        $midnightMoins1SecondTimestamp = strtotime($midnightMoins1SecondDate->format('H:i:s'));
+        $midnightMoinsDelayDate = new DateTime('midnight -' . $delay . 'seconds');
+        $midnightMoinsDelayTimestamp = strtotime($midnightMoinsDelayDate->format('H:i'));
+
+        $downtimeStartTimeTimestamp = strtotime($downtimeStartTime);
+
+        // YYYY-MM-DD 00:00:00
+        $midnightDate = new DateTime('midnight');
+        // 00:00
+        $midnight = $midnightDate->format('H:i');
+        $midnightTimestamp = strtotime($midnight);
+
+        // YYYY-MM-DD 00:00:10 (for 600 seconds delay)
+        $midnightPlusDelayDate = new DateTime('midnight +' . $delay . 'seconds');
+        // 00:10 (for 600 seconds delay)
+        $midnightPlusDelay = $midnightPlusDelayDate->format('H:i');
+        $midnightPlusDelayTimestamp = strtotime($midnightPlusDelay);
+
+        if ($downtimeStartTimeTimestamp >= $midnightTimestamp
+            && $downtimeStartTimeTimestamp <= $midnightPlusDelayTimestamp
+            && $nowTimestamp <= $midnightMoins1SecondTimestamp
+            && $nowTimestamp >= $midnightMoinsDelayTimestamp
+        ) {
+            $tomorrow = true;
+        }
+
+        return $tomorrow;
+    }
+
+    /**
+     * @param $downtimeStart
+     * @param $delayStart
+     * @param $delayEnd
+     *
+     * @return bool
+     */
+    private function isApproachingTime($downtimeStart, $delayStart, $delayEnd)
+    {
+        $approachingTime = false;
+        if ($downtimeStart >= $delayStart && $downtimeStart <= $delayEnd) {
+            $approachingTime = true;
+        }
+
+        return $approachingTime;
+    }
+
+    /**
+     * reset timestamp at beginning of hour if we jump forward
+     * example:
+     *   - current date is 2021-03-28
+     *   - $time is 02:30
+     *   ==> return timestamp corresponding to 02:00 cause 02:30 does not exist (jump from 02:00 to 03:00)
+     *
+     * @param DateTime $datetime
+     * @param string $time time formatted as HH:mm
+     *
+     * @return int the calculated timestamp
+     */
+    private function manageWinterToSummerTimestamp(DateTime $datetime, string $time): int
+    {
+        $hour = explode(':', $time)[0];
+        if ((int) $datetime->format('H') > (int) $hour) {
+            $datetime->setTime($hour, '00');
+        }
+
+        return $datetime->getTimestamp();
+    }
+
+    /**
+     * @param Datetime $dateTime
+     *
+     * @return int
+     */
+    private function manageSummerToWinterTimestamp(DateTime $dateTime)
+    {
+        $datetimePlusOneHour = clone $dateTime;
+        $datetimePlusOneHour->sub(new DateInterval('PT1H'));
+        if ($datetimePlusOneHour->format('H:m') === $dateTime->format('H:m')) {
+            return $dateTime->getTimestamp() - 3600;
+        }
+
+        return $dateTime->getTimestamp();
+    }
 }
