@@ -1,12 +1,13 @@
 <?php
+
 /*
- * Copyright 2005 - 2019 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,8 +21,8 @@
 
 namespace ConfigGenerateRemote;
 
-use \PDO;
 use ConfigGenerateRemote\Abstracts\AbstractObject;
+use PDO;
 
 /**
  * Class
@@ -31,12 +32,12 @@ use ConfigGenerateRemote\Abstracts\AbstractObject;
  */
 class Graph extends AbstractObject
 {
-    /** @var array|null */
-    private $graphs = null;
     /** @var string */
     protected $table = 'giv_graphs_template';
+
     /** @var string */
     protected $generateFilename = 'graph.infile';
+
     /** @var string */
     protected $attributesSelect = '
         graph_id,
@@ -54,6 +55,7 @@ class Graph extends AbstractObject
         scaled,
         comment
     ';
+
     /** @var string[] */
     protected $attributesWrite = [
         'graph_id',
@@ -69,31 +71,19 @@ class Graph extends AbstractObject
         'stacked',
         'split_component',
         'scaled',
-        'comment'
+        'comment',
     ];
 
-    /**
-     * Get graph
-     *
-     * @return void
-     */
-    private function getGraph(): void
-    {
-        $stmt = $this->backendInstance->db->prepare(
-            "SELECT $this->attributesSelect
-            FROM giv_graphs_template"
-        );
-        $stmt->execute();
-        $this->graphs = $stmt->fetchAll(PDO::FETCH_GROUP | PDO::FETCH_UNIQUE | PDO::FETCH_ASSOC);
-    }
+    /** @var array|null */
+    private $graphs = null;
 
     /**
      * Generate and get graph from id
      *
      * @param null|int $graphId
      *
-     * @return string|null
      * @throws \Exception
+     * @return string|null
      */
     public function getGraphFromId(?int $graphId)
     {
@@ -102,7 +92,7 @@ class Graph extends AbstractObject
         }
 
         $result = null;
-        if (!is_null($graphId) && isset($this->graphs[$graphId])) {
+        if (! is_null($graphId) && isset($this->graphs[$graphId])) {
             $result = $this->graphs[$graphId]['name'];
             if ($this->checkGenerate($graphId)) {
                 return $result;
@@ -112,4 +102,19 @@ class Graph extends AbstractObject
 
         return $result;
     }
+
+    /**
+     * Get graph
+     *
+     * @return void
+     */
+    private function getGraph(): void
+    {
+        $stmt = $this->backendInstance->db->prepare(
+            "SELECT {$this->attributesSelect}
+            FROM giv_graphs_template"
+        );
+        $stmt->execute();
+        $this->graphs = $stmt->fetchAll(PDO::FETCH_GROUP | PDO::FETCH_UNIQUE | PDO::FETCH_ASSOC);
+    }
 }
