@@ -1,34 +1,19 @@
 <?php
 
 /*
- * Copyright 2005-2015 Centreon
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -47,58 +32,36 @@ class Hostgroup extends AbstractObject
     private const TAG_FILENAME = 'tags.cfg';
     private const TAG_OBJECT_NAME = 'tag';
 
-    /** @var array */
-    private $hg = [];
     /** @var string */
     protected $generate_filename = self::HOSTGROUP_FILENAME;
+
     /** @var string */
     protected string $object_name = self::HOSTGROUP_OBJECT_NAME;
+
     /** @var string */
     protected $attributes_select = '
         hg_id,
         hg_name as hostgroup_name,
-        hg_alias as alias,
-        hg_notes as notes,
-        hg_notes_url as notes_url,
-        hg_action_url as action_url
+        hg_alias as alias
     ';
+
     /** @var null */
     protected $stmt_hg = null;
 
-    /**
-     * @param $hg_id
-     *
-     * @return void
-     * @throws PDOException
-     */
-    private function getHostgroupFromId($hg_id): void
-    {
-        if (is_null($this->stmt_hg)) {
-            $this->stmt_hg = $this->backend_instance->db->prepare(
-                "SELECT  $this->attributes_select
-                FROM hostgroup
-                WHERE hg_id = :hg_id AND hg_activate = '1'"
-            );
-        }
-        $this->stmt_hg->bindParam(':hg_id', $hg_id, PDO::PARAM_INT);
-        $this->stmt_hg->execute();
-        if ($hostGroup = $this->stmt_hg->fetch(\PDO::FETCH_ASSOC)) {
-            $this->hg[$hg_id] = $hostGroup;
-            $this->hg[$hg_id]['members'] = [];
-        }
-    }
+    /** @var array */
+    private $hg = [];
 
     /**
      * @param $hg_id
      * @param $host_id
      * @param $host_name
      *
-     * @return int
      * @throws PDOException
+     * @return int
      */
     public function addHostInHg($hg_id, $host_id, $host_name)
     {
-        if (!isset($this->hg[$hg_id])) {
+        if (! isset($this->hg[$hg_id])) {
             $this->getHostgroupFromId($hg_id);
         }
         if (is_null($this->hg[$hg_id]) || isset($this->hg[$hg_id]['members'][$host_id])) {
@@ -106,6 +69,7 @@ class Hostgroup extends AbstractObject
         }
 
         $this->hg[$hg_id]['members'][$host_id] = $host_name;
+
         return 0;
     }
 
@@ -118,6 +82,70 @@ class Hostgroup extends AbstractObject
         $this->generateTags();
     }
 
+    /**
+     * @return array
+     */
+    public function getHostgroups()
+    {
+        $result = [];
+        foreach ($this->hg as $id => &$value) {
+            if (is_null($value) || count($value['members']) == 0) {
+                continue;
+            }
+            $result[$id] = &$value;
+        }
+
+        return $result;
+    }
+
+    /**
+     * @throws Exception
+     * @return void
+     */
+    public function reset(): void
+    {
+        parent::reset();
+        foreach ($this->hg as &$value) {
+            if (! is_null($value)) {
+                $value['members'] = [];
+            }
+        }
+    }
+
+    /**
+     * @param $hg_id
+     * @param $attr
+     *
+     * @return mixed|null
+     */
+    public function getString($hg_id, $attr)
+    {
+        return $this->hg[$hg_id][$attr] ?? null;
+    }
+
+    /**
+     * @param $hg_id
+     *
+     * @throws PDOException
+     * @return void
+     */
+    private function getHostgroupFromId($hg_id): void
+    {
+        if (is_null($this->stmt_hg)) {
+            $this->stmt_hg = $this->backend_instance->db->prepare(
+                "SELECT  {$this->attributes_select}
+                FROM hostgroup
+                WHERE hg_id = :hg_id AND hg_activate = '1'"
+            );
+        }
+        $this->stmt_hg->bindParam(':hg_id', $hg_id, PDO::PARAM_INT);
+        $this->stmt_hg->execute();
+        if ($hostGroup = $this->stmt_hg->fetch(PDO::FETCH_ASSOC)) {
+            $this->hg[$hg_id] = $hostGroup;
+            $this->hg[$hg_id]['members'] = [];
+        }
+    }
+
     /**
      * Generate host groups and write in file
      */
@@ -129,9 +157,6 @@ class Hostgroup extends AbstractObject
             'hostgroup_id',
             'hostgroup_name',
             'alias',
-            'notes',
-            'notes_url',
-            'action_url',
         ];
         $this->attributes_array = [
             'members',
@@ -181,44 +206,4 @@ class Hostgroup extends AbstractObject
             $this->generateObjectInFile($tag, $id);
         }
     }
-
-    /**
-     * @return array
-     */
-    public function getHostgroups()
-    {
-        $result = [];
-        foreach ($this->hg as $id => &$value) {
-            if (is_null($value) || count($value['members']) == 0) {
-                continue;
-            }
-            $result[$id] = &$value;
-        }
-        return $result;
-    }
-
-    /**
-     * @return void
-     * @throws Exception
-     */
-    public function reset(): void
-    {
-        parent::reset();
-        foreach ($this->hg as &$value) {
-            if (!is_null($value)) {
-                $value['members'] = [];
-            }
-        }
-    }
-
-    /**
-     * @param $hg_id
-     * @param $attr
-     *
-     * @return mixed|null
-     */
-    public function getString($hg_id, $attr)
-    {
-        return $this->hg[$hg_id][$attr] ?? null;
-    }
 }
