@@ -69,10 +69,9 @@ const useFormInputs = (): FormInputsState => {
       connectedAutocomplete: {
         additionalConditionParameters: [userSearchConditions],
         endpoint: listUsers,
-        getRenderedOptionText: (option): string =>
-          option.alias?.toString() || '',
+        getRenderedOptionText: (option): string => option.alias?.toString(),
         filterKey: 'alias',
-        getOptionLabel: (option): string => option?.alias || ''
+        getOptionLabel: (option): string => option?.alias
       },
       fieldName: 'user',
       hideInput: (values) => equals(values?.type?.id, TokenType.CMA),
