@@ -3,6 +3,11 @@ export interface NamedEntity {
   name: string;
 }
 
+export interface User {
+  id: number;
+  alias: string;
+}
+
 export enum TokenType {
   API = 'api',
   CMA = 'cma'
@@ -17,7 +22,7 @@ export interface ModalState {
 export interface Filter {
   name: string;
   types: Array<NamedEntity>;
-  users: Array<NamedEntity>;
+  users: Array<User>;
   creators: Array<NamedEntity>;
   expirationDate: Date | null;
   creationDate: Date | null;
