@@ -94,8 +94,12 @@ const AddCommentArea = ({
         required
         ariaLabel={t(labelComment)}
         autoComplete="off"
-        inputProps={{
-          'data-testid': 'commentArea'
+        textFieldSlotsAndSlotProps={{
+          slotProps: {
+            htmlInput: {
+              'data-testid': 'commentArea'
+            }
+          }
         }}
         label={t(labelComment)}
         rows={3}
