@@ -22,18 +22,25 @@ if (! isset($oreon)) {
     exit;
 }
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\Exception\ConnectionException;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
+
 // Database retrieve information
 $vmetric = [];
 
 if (($o == METRIC_MODIFY || $o == METRIC_WATCH)
     && is_int($vmetricId)
 ) {
-    $query = "SELECT *, hidden vhidden FROM virtual_metrics WHERE vmetric_id = {$vmetricId} LIMIT 1";
-    $p_qy = $pearDB->query($query);
-    // Set base value
-    $vmetric = array_map('myDecode', $p_qy->fetchRow());
-    $p_qy->closeCursor();
+    $virtualMetricResult = $pearDB->fetchAssociative(
+        'SELECT *, hidden vhidden FROM virtual_metrics WHERE vmetric_id = :vmetric_id LIMIT 1',
+        new QueryParameters([
+            QueryParameter::int('vmetric_id', $vmetricId),
+        ])
+    );
+    $vmetric = array_map('myDecode', $virtualMetricResult ?? []);
 }
+
 /*
  * Database retrieve information and list the different elements we need on the page
  *
@@ -43,23 +50,20 @@ $indds = ['' => sprintf('%s%s', _('Host list'), '&nbsp;&nbsp;&nbsp;')];
 $mx_l = strlen($indds['']);
 
 try {
-    $dbindd = $pearDBO->query('SELECT DISTINCT 1 AS REALTIME, host_id, host_name FROM index_data;');
-} catch (PDOException $e) {
+    $dbindd = $pearDBO->fetchAllAssociative('SELECT DISTINCT 1 AS REALTIME, host_id, host_name FROM index_data;');
+} catch (ConnectionException $e) {
     echo 'DB Error : ' . $e->getMessage() . '<br />';
 }
-while ($indd = $dbindd->fetchRow()) {
+foreach ($dbindd as $indd) {
     $indds[$indd['host_id']] = $indd['host_name'] . '&nbsp;&nbsp;&nbsp;';
     $hn_l = strlen($indd['host_name']);
     if ($hn_l > $mx_l) {
         $mx_l = $hn_l;
     }
 }
-$dbindd->closeCursor();
-
 // End of "database-retrieved" information
 
 // Var information to format the element
-
 $attrsText = ['size' => '30'];
 $attrsText2 = ['size' => '10'];
 $attrsAdvSelect = ['style' => 'width: 200px; height: 100px;'];
@@ -288,11 +292,11 @@ $vdef = 1; // Display VDEF too
 
 if ($o == METRIC_MODIFY || $o == METRIC_WATCH) {
     $host_service_id = isset($_POST['host_id']) && $_POST['host_id'] != null
-        ? $_POST['host_id']
+        ? filter_var($_POST['host_id'], FILTER_SANITIZE_NUMBER_INT)
         : $vmetric['host_id'];
 } elseif ($o == METRIC_ADD) {
     $host_service_id = isset($_POST['host_id']) && $_POST['host_id'] != null
-        ? $_POST['host_id']
+        ? filter_var($_POST['host_id'], FILTER_SANITIZE_NUMBER_INT)
         : 0;
 }
 ?>
