@@ -89,11 +89,13 @@ function createLink(array $preferences): string
             . $preferences['sort']
             . '&limit='
             . $preferences['top']
-            . (! empty($preferences['filter-address'])
+            . (
+                ! empty($preferences['filter-address'])
                 ? '&host=' . $preferences['filter-address']
                 : ''
             )
-            . (! empty($preferences['filter-port'])
+            . (
+                ! empty($preferences['filter-port'])
                 ? '&port=' . $preferences['filter-port']
                 : ''
             ),
